pyesmda.ESMDA
=============

.. currentmodule:: pyesmda

.. autoclass:: ESMDA
   :members:                                    <-- add at least this line
   :private-members:
   :show-inheritance:                           <-- plus I want to show inheritance...
   :inherited-members:                          <-- ...and inherited members too

   
   .. automethod:: __init__

   
   .. rubric:: Public methods summary

   .. autosummary::
   
      ~ESMDA.__delattr__
      ~ESMDA.__dir__
      ~ESMDA.__eq__
      ~ESMDA.__format__
      ~ESMDA.__ge__
      ~ESMDA.__getattribute__
      ~ESMDA.__gt__
      ~ESMDA.__hash__
      ~ESMDA.__init__
      ~ESMDA.__init_subclass__
      ~ESMDA.__le__
      ~ESMDA.__lt__
      ~ESMDA.__ne__
      ~ESMDA.__new__
      ~ESMDA.__reduce__
      ~ESMDA.__reduce_ex__
      ~ESMDA.__repr__
      ~ESMDA.__setattr__
      ~ESMDA.__sizeof__
      ~ESMDA.__str__
      ~ESMDA.__subclasshook__
      ~ESMDA._analyse
      ~ESMDA._apply_bounds
      ~ESMDA._approximate_covariance_matrices
      ~ESMDA._forecast
      ~ESMDA._get_batch_m_update
      ~ESMDA._local_analyse
      ~ESMDA._pertrub
      ~ESMDA._set_n_assimilations
      ~ESMDA._solve
      ~ESMDA._solve_locally
      ~ESMDA.set_cov_obs_inflation_factors
      ~ESMDA.solve
   
   
   

   .. rubric:: Methods definition